Class: Google::Cloud::TextToSpeech::V1::CustomVoiceParams

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/texttospeech/v1/cloud_tts.rb

Overview

Description of the custom voice to be synthesized.

Defined Under Namespace

Modules: ReportedUsage

Instance Attribute Summary collapse

Instance Attribute Details

#model::String

Returns Required. The name of the AutoML model that synthesizes the custom voice.

Returns:

  • (::String)

    Required. The name of the AutoML model that synthesizes the custom voice.



444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
# File 'proto_docs/google/cloud/texttospeech/v1/cloud_tts.rb', line 444

class CustomVoiceParams
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Deprecated. The usage of the synthesized audio. Usage does not affect
  # billing.
  module ReportedUsage
    # Request with reported usage unspecified will be rejected.
    REPORTED_USAGE_UNSPECIFIED = 0

    # For scenarios where the synthesized audio is not downloadable and can
    # only be used once. For example, real-time request in IVR system.
    REALTIME = 1

    # For scenarios where the synthesized audio is downloadable and can be
    # reused. For example, the synthesized audio is downloaded, stored in
    # customer service system and played repeatedly.
    OFFLINE = 2
  end
end

#reported_usage::Google::Cloud::TextToSpeech::V1::CustomVoiceParams::ReportedUsage

Deprecated.

This field is deprecated and may be removed in the next major version update.

Returns Optional. Deprecated. The usage of the synthesized audio to be reported.

Returns:



444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
# File 'proto_docs/google/cloud/texttospeech/v1/cloud_tts.rb', line 444

class CustomVoiceParams
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Deprecated. The usage of the synthesized audio. Usage does not affect
  # billing.
  module ReportedUsage
    # Request with reported usage unspecified will be rejected.
    REPORTED_USAGE_UNSPECIFIED = 0

    # For scenarios where the synthesized audio is not downloadable and can
    # only be used once. For example, real-time request in IVR system.
    REALTIME = 1

    # For scenarios where the synthesized audio is downloadable and can be
    # reused. For example, the synthesized audio is downloaded, stored in
    # customer service system and played repeatedly.
    OFFLINE = 2
  end
end