Class: Google::Cloud::TextToSpeech::V1::AdvancedVoiceOptions
- Inherits:
-
Object
- Object
- Google::Cloud::TextToSpeech::V1::AdvancedVoiceOptions
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/texttospeech/v1/cloud_tts.rb
Overview
Used for advanced voice options.
Defined Under Namespace
Modules: HarmBlockThreshold, HarmCategory Classes: SafetySetting, SafetySettings
Instance Attribute Summary collapse
-
#enable_textnorm ⇒ ::Boolean
Optional.
-
#low_latency_journey_synthesis ⇒ ::Boolean
Only for Journey voices.
-
#relax_safety_filters ⇒ ::Boolean
deprecated
Deprecated.
This field is deprecated and may be removed in the next major version update.
-
#safety_settings ⇒ ::Google::Cloud::TextToSpeech::V1::AdvancedVoiceOptions::SafetySettings
Optional.
Instance Attribute Details
#enable_textnorm ⇒ ::Boolean
Returns Optional. If true, textnorm will be applied to text input. This feature is enabled by default. Only applies for Gemini TTS.
89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 |
# File 'proto_docs/google/cloud/texttospeech/v1/cloud_tts.rb', line 89 class AdvancedVoiceOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Safety setting for a single harm category. # @!attribute [rw] category # @return [::Google::Cloud::TextToSpeech::V1::AdvancedVoiceOptions::HarmCategory] # The harm category to apply the safety setting to. # @!attribute [rw] threshold # @return [::Google::Cloud::TextToSpeech::V1::AdvancedVoiceOptions::HarmBlockThreshold] # The harm block threshold for the safety setting. class SafetySetting include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Safety settings for the request. # @!attribute [rw] settings # @return [::Array<::Google::Cloud::TextToSpeech::V1::AdvancedVoiceOptions::SafetySetting>] # The safety settings for the request. class SafetySettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Harm categories that will block the content. module HarmCategory # Default value. This value is unused. HARM_CATEGORY_UNSPECIFIED = 0 # Content that promotes violence or incites hatred against individuals or # groups based on certain attributes. HARM_CATEGORY_HATE_SPEECH = 1 # Content that promotes, facilitates, or enables dangerous activities. HARM_CATEGORY_DANGEROUS_CONTENT = 2 # Abusive, threatening, or content intended to bully, torment, or ridicule. HARM_CATEGORY_HARASSMENT = 3 # Content that contains sexually explicit material. HARM_CATEGORY_SEXUALLY_EXPLICIT = 4 end # Harm block thresholds for the safety settings. module HarmBlockThreshold # The harm block threshold is unspecified. HARM_BLOCK_THRESHOLD_UNSPECIFIED = 0 # Block content with a low harm probability or higher. BLOCK_LOW_AND_ABOVE = 1 # Block content with a medium harm probability or higher. BLOCK_MEDIUM_AND_ABOVE = 2 # Block content with a high harm probability. BLOCK_ONLY_HIGH = 3 # Do not block any content, regardless of its harm probability. BLOCK_NONE = 4 # Turn off the safety filter entirely. OFF = 5 end end |
#low_latency_journey_synthesis ⇒ ::Boolean
Returns Only for Journey voices. If false, the synthesis is context aware and has a higher latency.
89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 |
# File 'proto_docs/google/cloud/texttospeech/v1/cloud_tts.rb', line 89 class AdvancedVoiceOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Safety setting for a single harm category. # @!attribute [rw] category # @return [::Google::Cloud::TextToSpeech::V1::AdvancedVoiceOptions::HarmCategory] # The harm category to apply the safety setting to. # @!attribute [rw] threshold # @return [::Google::Cloud::TextToSpeech::V1::AdvancedVoiceOptions::HarmBlockThreshold] # The harm block threshold for the safety setting. class SafetySetting include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Safety settings for the request. # @!attribute [rw] settings # @return [::Array<::Google::Cloud::TextToSpeech::V1::AdvancedVoiceOptions::SafetySetting>] # The safety settings for the request. class SafetySettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Harm categories that will block the content. module HarmCategory # Default value. This value is unused. HARM_CATEGORY_UNSPECIFIED = 0 # Content that promotes violence or incites hatred against individuals or # groups based on certain attributes. HARM_CATEGORY_HATE_SPEECH = 1 # Content that promotes, facilitates, or enables dangerous activities. HARM_CATEGORY_DANGEROUS_CONTENT = 2 # Abusive, threatening, or content intended to bully, torment, or ridicule. HARM_CATEGORY_HARASSMENT = 3 # Content that contains sexually explicit material. HARM_CATEGORY_SEXUALLY_EXPLICIT = 4 end # Harm block thresholds for the safety settings. module HarmBlockThreshold # The harm block threshold is unspecified. HARM_BLOCK_THRESHOLD_UNSPECIFIED = 0 # Block content with a low harm probability or higher. BLOCK_LOW_AND_ABOVE = 1 # Block content with a medium harm probability or higher. BLOCK_MEDIUM_AND_ABOVE = 2 # Block content with a high harm probability. BLOCK_ONLY_HIGH = 3 # Do not block any content, regardless of its harm probability. BLOCK_NONE = 4 # Turn off the safety filter entirely. OFF = 5 end end |
#relax_safety_filters ⇒ ::Boolean
This field is deprecated and may be removed in the next major version update.
Returns Optional. Input only. Deprecated, use safety_settings instead. If true, relaxes safety filters for Gemini TTS.
89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 |
# File 'proto_docs/google/cloud/texttospeech/v1/cloud_tts.rb', line 89 class AdvancedVoiceOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Safety setting for a single harm category. # @!attribute [rw] category # @return [::Google::Cloud::TextToSpeech::V1::AdvancedVoiceOptions::HarmCategory] # The harm category to apply the safety setting to. # @!attribute [rw] threshold # @return [::Google::Cloud::TextToSpeech::V1::AdvancedVoiceOptions::HarmBlockThreshold] # The harm block threshold for the safety setting. class SafetySetting include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Safety settings for the request. # @!attribute [rw] settings # @return [::Array<::Google::Cloud::TextToSpeech::V1::AdvancedVoiceOptions::SafetySetting>] # The safety settings for the request. class SafetySettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Harm categories that will block the content. module HarmCategory # Default value. This value is unused. HARM_CATEGORY_UNSPECIFIED = 0 # Content that promotes violence or incites hatred against individuals or # groups based on certain attributes. HARM_CATEGORY_HATE_SPEECH = 1 # Content that promotes, facilitates, or enables dangerous activities. HARM_CATEGORY_DANGEROUS_CONTENT = 2 # Abusive, threatening, or content intended to bully, torment, or ridicule. HARM_CATEGORY_HARASSMENT = 3 # Content that contains sexually explicit material. HARM_CATEGORY_SEXUALLY_EXPLICIT = 4 end # Harm block thresholds for the safety settings. module HarmBlockThreshold # The harm block threshold is unspecified. HARM_BLOCK_THRESHOLD_UNSPECIFIED = 0 # Block content with a low harm probability or higher. BLOCK_LOW_AND_ABOVE = 1 # Block content with a medium harm probability or higher. BLOCK_MEDIUM_AND_ABOVE = 2 # Block content with a high harm probability. BLOCK_ONLY_HIGH = 3 # Do not block any content, regardless of its harm probability. BLOCK_NONE = 4 # Turn off the safety filter entirely. OFF = 5 end end |
#safety_settings ⇒ ::Google::Cloud::TextToSpeech::V1::AdvancedVoiceOptions::SafetySettings
Returns Optional. Input only. This applies to Gemini TTS only. If set, the category specified in the safety setting will be blocked if the harm probability is above the threshold. Otherwise, the safety filter will be disabled by default.
89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 |
# File 'proto_docs/google/cloud/texttospeech/v1/cloud_tts.rb', line 89 class AdvancedVoiceOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Safety setting for a single harm category. # @!attribute [rw] category # @return [::Google::Cloud::TextToSpeech::V1::AdvancedVoiceOptions::HarmCategory] # The harm category to apply the safety setting to. # @!attribute [rw] threshold # @return [::Google::Cloud::TextToSpeech::V1::AdvancedVoiceOptions::HarmBlockThreshold] # The harm block threshold for the safety setting. class SafetySetting include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Safety settings for the request. # @!attribute [rw] settings # @return [::Array<::Google::Cloud::TextToSpeech::V1::AdvancedVoiceOptions::SafetySetting>] # The safety settings for the request. class SafetySettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Harm categories that will block the content. module HarmCategory # Default value. This value is unused. HARM_CATEGORY_UNSPECIFIED = 0 # Content that promotes violence or incites hatred against individuals or # groups based on certain attributes. HARM_CATEGORY_HATE_SPEECH = 1 # Content that promotes, facilitates, or enables dangerous activities. HARM_CATEGORY_DANGEROUS_CONTENT = 2 # Abusive, threatening, or content intended to bully, torment, or ridicule. HARM_CATEGORY_HARASSMENT = 3 # Content that contains sexually explicit material. HARM_CATEGORY_SEXUALLY_EXPLICIT = 4 end # Harm block thresholds for the safety settings. module HarmBlockThreshold # The harm block threshold is unspecified. HARM_BLOCK_THRESHOLD_UNSPECIFIED = 0 # Block content with a low harm probability or higher. BLOCK_LOW_AND_ABOVE = 1 # Block content with a medium harm probability or higher. BLOCK_MEDIUM_AND_ABOVE = 2 # Block content with a high harm probability. BLOCK_ONLY_HIGH = 3 # Do not block any content, regardless of its harm probability. BLOCK_NONE = 4 # Turn off the safety filter entirely. OFF = 5 end end |