Module: Google::Cloud::TextToSpeech::V1::AdvancedVoiceOptions::HarmBlockThreshold
- Defined in:
- proto_docs/google/cloud/texttospeech/v1/cloud_tts.rb
Overview
Harm block thresholds for the safety settings.
Constant Summary collapse
- HARM_BLOCK_THRESHOLD_UNSPECIFIED =
The harm block threshold is unspecified.
0- BLOCK_LOW_AND_ABOVE =
Block content with a low harm probability or higher.
1- BLOCK_MEDIUM_AND_ABOVE =
Block content with a medium harm probability or higher.
2- BLOCK_ONLY_HIGH =
Block content with a high harm probability.
3- BLOCK_NONE =
Do not block any content, regardless of its harm probability.
4- OFF =
Turn off the safety filter entirely.
5